from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Geom2d import *
from OCC.Core.TColGeom2d import *
from OCC.Core.TColStd import *
from OCC.Core.Convert import *
from OCC.Core.GeomAbs import *
from OCC.Core.Adaptor2d import *


class geom2dconvert:
	@overload
	@staticmethod
	def C0BSplineToArrayOfC1BSplineCurve(BS: Geom2d_BSplineCurve, tabBS: TColGeom2d_HArray1OfBSplineCurve, Tolerance: float) -> None: ...
	@overload
	@staticmethod
	def C0BSplineToArrayOfC1BSplineCurve(BS: Geom2d_BSplineCurve, tabBS: TColGeom2d_HArray1OfBSplineCurve, AngularTolerance: float, Tolerance: float) -> None: ...
	@staticmethod
	def C0BSplineToC1BSplineCurve(BS: Geom2d_BSplineCurve, Tolerance: float) -> None: ...
	@overload
	@staticmethod
	def ConcatC1(ArrayOfCurves: TColGeom2d_Array1OfBSplineCurve, ArrayOfToler: TColStd_Array1OfReal, ArrayOfIndices: TColStd_HArray1OfInteger, ArrayOfConcatenated: TColGeom2d_HArray1OfBSplineCurve, ClosedTolerance: float) -> bool: ...
	@overload
	@staticmethod
	def ConcatC1(ArrayOfCurves: TColGeom2d_Array1OfBSplineCurve, ArrayOfToler: TColStd_Array1OfReal, ArrayOfIndices: TColStd_HArray1OfInteger, ArrayOfConcatenated: TColGeom2d_HArray1OfBSplineCurve, ClosedTolerance: float, AngularTolerance: float) -> bool: ...
	@staticmethod
	def ConcatG1(ArrayOfCurves: TColGeom2d_Array1OfBSplineCurve, ArrayOfToler: TColStd_Array1OfReal, ArrayOfConcatenated: TColGeom2d_HArray1OfBSplineCurve, ClosedTolerance: float) -> bool: ...
	@staticmethod
	def CurveToBSplineCurve(C: Geom2d_Curve, Parameterisation: Optional[Convert_ParameterisationType] = Convert_TgtThetaOver2) -> Geom2d_BSplineCurve: ...
	@overload
	@staticmethod
	def SplitBSplineCurve(C: Geom2d_BSplineCurve, FromK1: int, ToK2: int, SameOrientation: Optional[bool] = True) -> Geom2d_BSplineCurve: ...
	@overload
	@staticmethod
	def SplitBSplineCurve(C: Geom2d_BSplineCurve, FromU1: float, ToU2: float, ParametricTolerance: float, SameOrientation: Optional[bool] = True) -> Geom2d_BSplineCurve: ...

class Geom2dConvert_ApproxCurve:
	@overload
	def __init__(self, Curve: Geom2d_Curve, Tol2d: float, Order: GeomAbs_Shape, MaxSegments: int, MaxDegree: int) -> None: ...
	@overload
	def __init__(self, Curve: Adaptor2d_HCurve2d, Tol2d: float, Order: GeomAbs_Shape, MaxSegments: int, MaxDegree: int) -> None: ...
	def Curve(self) -> Geom2d_BSplineCurve: ...
	def HasResult(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def MaxError(self) -> float: ...

class Geom2dConvert_BSplineCurveKnotSplitting:
	def __init__(self, BasisCurve: Geom2d_BSplineCurve, ContinuityRange: int) -> None: ...
	def NbSplits(self) -> int: ...
	def SplitValue(self, Index: int) -> int: ...
	def Splitting(self, SplitValues: TColStd_Array1OfInteger) -> None: ...

class Geom2dConvert_BSplineCurveToBezierCurve:
	@overload
	def __init__(self, BasisCurve: Geom2d_BSplineCurve) -> None: ...
	@overload
	def __init__(self, BasisCurve: Geom2d_BSplineCurve, U1: float, U2: float, ParametricTolerance: float) -> None: ...
	def Arc(self, Index: int) -> Geom2d_BezierCurve: ...
	def Arcs(self, Curves: TColGeom2d_Array1OfBezierCurve) -> None: ...
	def Knots(self, TKnots: TColStd_Array1OfReal) -> None: ...
	def NbArcs(self) -> int: ...

class Geom2dConvert_CompCurveToBSplineCurve:
	@overload
	def __init__(self, Parameterisation: Optional[Convert_ParameterisationType] = Convert_TgtThetaOver2) -> None: ...
	@overload
	def __init__(self, BasisCurve: Geom2d_BoundedCurve, Parameterisation: Optional[Convert_ParameterisationType] = Convert_TgtThetaOver2) -> None: ...
	def Add(self, NewCurve: Geom2d_BoundedCurve, Tolerance: float, After: Optional[bool] = False) -> bool: ...
	def BSplineCurve(self) -> Geom2d_BSplineCurve: ...
	def Clear(self) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

geom2dconvert_C0BSplineToArrayOfC1BSplineCurve = geom2dconvert.C0BSplineToArrayOfC1BSplineCurve
geom2dconvert_C0BSplineToArrayOfC1BSplineCurve = geom2dconvert.C0BSplineToArrayOfC1BSplineCurve
geom2dconvert_C0BSplineToC1BSplineCurve = geom2dconvert.C0BSplineToC1BSplineCurve
geom2dconvert_ConcatC1 = geom2dconvert.ConcatC1
geom2dconvert_ConcatC1 = geom2dconvert.ConcatC1
geom2dconvert_ConcatG1 = geom2dconvert.ConcatG1
geom2dconvert_CurveToBSplineCurve = geom2dconvert.CurveToBSplineCurve
geom2dconvert_SplitBSplineCurve = geom2dconvert.SplitBSplineCurve
geom2dconvert_SplitBSplineCurve = geom2dconvert.SplitBSplineCurve



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TCollection import *


class Resource_FormatType(IntEnum):
	Resource_FormatType_SJIS: int = ...
	Resource_FormatType_EUC: int = ...
	Resource_FormatType_NoConversion: int = ...
	Resource_FormatType_GB: int = ...
	Resource_FormatType_UTF8: int = ...
	Resource_FormatType_SystemLocale: int = ...
	Resource_FormatType_CP1250: int = ...
	Resource_FormatType_CP1251: int = ...
	Resource_FormatType_CP1252: int = ...
	Resource_FormatType_CP1253: int = ...
	Resource_FormatType_CP1254: int = ...
	Resource_FormatType_CP1255: int = ...
	Resource_FormatType_CP1256: int = ...
	Resource_FormatType_CP1257: int = ...
	Resource_FormatType_CP1258: int = ...
	Resource_FormatType_iso8859_1: int = ...
	Resource_FormatType_iso8859_2: int = ...
	Resource_FormatType_iso8859_3: int = ...
	Resource_FormatType_iso8859_4: int = ...
	Resource_FormatType_iso8859_5: int = ...
	Resource_FormatType_iso8859_6: int = ...
	Resource_FormatType_iso8859_7: int = ...
	Resource_FormatType_iso8859_8: int = ...
	Resource_FormatType_iso8859_9: int = ...
	Resource_FormatType_GBK: int = ...
	Resource_FormatType_Big5: int = ...
	Resource_FormatType_ANSI: int = ...
	Resource_SJIS: int = ...
	Resource_EUC: int = ...
	Resource_ANSI: int = ...
	Resource_GB: int = ...
Resource_FormatType_SJIS = Resource_FormatType.Resource_FormatType_SJIS
Resource_FormatType_EUC = Resource_FormatType.Resource_FormatType_EUC
Resource_FormatType_NoConversion = Resource_FormatType.Resource_FormatType_NoConversion
Resource_FormatType_GB = Resource_FormatType.Resource_FormatType_GB
Resource_FormatType_UTF8 = Resource_FormatType.Resource_FormatType_UTF8
Resource_FormatType_SystemLocale = Resource_FormatType.Resource_FormatType_SystemLocale
Resource_FormatType_CP1250 = Resource_FormatType.Resource_FormatType_CP1250
Resource_FormatType_CP1251 = Resource_FormatType.Resource_FormatType_CP1251
Resource_FormatType_CP1252 = Resource_FormatType.Resource_FormatType_CP1252
Resource_FormatType_CP1253 = Resource_FormatType.Resource_FormatType_CP1253
Resource_FormatType_CP1254 = Resource_FormatType.Resource_FormatType_CP1254
Resource_FormatType_CP1255 = Resource_FormatType.Resource_FormatType_CP1255
Resource_FormatType_CP1256 = Resource_FormatType.Resource_FormatType_CP1256
Resource_FormatType_CP1257 = Resource_FormatType.Resource_FormatType_CP1257
Resource_FormatType_CP1258 = Resource_FormatType.Resource_FormatType_CP1258
Resource_FormatType_iso8859_1 = Resource_FormatType.Resource_FormatType_iso8859_1
Resource_FormatType_iso8859_2 = Resource_FormatType.Resource_FormatType_iso8859_2
Resource_FormatType_iso8859_3 = Resource_FormatType.Resource_FormatType_iso8859_3
Resource_FormatType_iso8859_4 = Resource_FormatType.Resource_FormatType_iso8859_4
Resource_FormatType_iso8859_5 = Resource_FormatType.Resource_FormatType_iso8859_5
Resource_FormatType_iso8859_6 = Resource_FormatType.Resource_FormatType_iso8859_6
Resource_FormatType_iso8859_7 = Resource_FormatType.Resource_FormatType_iso8859_7
Resource_FormatType_iso8859_8 = Resource_FormatType.Resource_FormatType_iso8859_8
Resource_FormatType_iso8859_9 = Resource_FormatType.Resource_FormatType_iso8859_9
Resource_FormatType_GBK = Resource_FormatType.Resource_FormatType_GBK
Resource_FormatType_Big5 = Resource_FormatType.Resource_FormatType_Big5
Resource_FormatType_ANSI = Resource_FormatType.Resource_FormatType_ANSI
Resource_SJIS = Resource_FormatType.Resource_SJIS
Resource_EUC = Resource_FormatType.Resource_EUC
Resource_ANSI = Resource_FormatType.Resource_ANSI
Resource_GB = Resource_FormatType.Resource_GB

class Resource_LexicalCompare:
	def __init__(self) -> None: ...
	def IsLower(self, Left: TCollection_AsciiString, Right: TCollection_AsciiString) -> bool: ...

class Resource_Manager(Standard_Transient):
	@overload
	def __init__(self, aName: str, Verbose: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, theName: TCollection_AsciiString, theDefaultsDirectory: TCollection_AsciiString, theUserDefaultsDirectory: TCollection_AsciiString, theIsVerbose: Optional[bool] = False) -> None: ...
	def ExtValue(self, aResourceName: str) -> Standard_ExtString: ...
	@overload
	def Find(self, aResource: str) -> bool: ...
	@overload
	def Find(self, theResource: TCollection_AsciiString, theValue: TCollection_AsciiString) -> bool: ...
	@staticmethod
	def GetResourcePath(aPath: TCollection_AsciiString, aName: str, isUserDefaults: bool) -> None: ...
	def Integer(self, aResourceName: str) -> int: ...
	def Real(self, aResourceName: str) -> float: ...
	def Save(self) -> bool: ...
	@overload
	def SetResource(self, aResourceName: str, aValue: int) -> None: ...
	@overload
	def SetResource(self, aResourceName: str, aValue: float) -> None: ...
	@overload
	def SetResource(self, aResourceName: str, aValue: str) -> None: ...
	@overload
	def SetResource(self, aResourceName: str, aValue: Standard_ExtString) -> None: ...
	def Value(self, aResourceName: str) -> str: ...

class Resource_Unicode:
	@staticmethod
	def ConvertBig5ToUnicode(fromstr: str, tostr: TCollection_ExtendedString) -> bool: ...
	@staticmethod
	def ConvertEUCToUnicode(fromstr: str, tostr: TCollection_ExtendedString) -> None: ...
	@overload
	@staticmethod
	def ConvertFormatToUnicode(theFromStr: str, theToStr: TCollection_ExtendedString) -> None: ...
	@overload
	@staticmethod
	def ConvertFormatToUnicode(theFormat: Resource_FormatType, theFromStr: str, theToStr: TCollection_ExtendedString) -> None: ...
	@staticmethod
	def ConvertGBKToUnicode(fromstr: str, tostr: TCollection_ExtendedString) -> bool: ...
	@staticmethod
	def ConvertGBToUnicode(fromstr: str, tostr: TCollection_ExtendedString) -> None: ...
	@staticmethod
	def ConvertSJISToUnicode(fromstr: str, tostr: TCollection_ExtendedString) -> None: ...
	@staticmethod
	def ConvertUnicodeToANSI(fromstr: TCollection_ExtendedString, tostr: Standard_PCharacter, maxsize: int) -> bool: ...
	@staticmethod
	def ConvertUnicodeToEUC(fromstr: TCollection_ExtendedString, tostr: Standard_PCharacter, maxsize: int) -> bool: ...
	@overload
	@staticmethod
	def ConvertUnicodeToFormat(theFormat: Resource_FormatType, theFromStr: TCollection_ExtendedString, theToStr: Standard_PCharacter, theMaxSize: int) -> bool: ...
	@overload
	@staticmethod
	def ConvertUnicodeToFormat(theFromStr: TCollection_ExtendedString, theToStr: Standard_PCharacter, theMaxSize: int) -> bool: ...
	@staticmethod
	def ConvertUnicodeToGB(fromstr: TCollection_ExtendedString, tostr: Standard_PCharacter, maxsize: int) -> bool: ...
	@staticmethod
	def ConvertUnicodeToSJIS(fromstr: TCollection_ExtendedString, tostr: Standard_PCharacter, maxsize: int) -> bool: ...
	@staticmethod
	def GetFormat() -> Resource_FormatType: ...
	@staticmethod
	def ReadFormat() -> None: ...
	@staticmethod
	def SetFormat(typecode: Resource_FormatType) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

Resource_Manager_GetResourcePath = Resource_Manager.GetResourcePath
Resource_Unicode_ConvertBig5ToUnicode = Resource_Unicode.ConvertBig5ToUnicode
Resource_Unicode_ConvertEUCToUnicode = Resource_Unicode.ConvertEUCToUnicode
Resource_Unicode_ConvertFormatToUnicode = Resource_Unicode.ConvertFormatToUnicode
Resource_Unicode_ConvertFormatToUnicode = Resource_Unicode.ConvertFormatToUnicode
Resource_Unicode_ConvertGBKToUnicode = Resource_Unicode.ConvertGBKToUnicode
Resource_Unicode_ConvertGBToUnicode = Resource_Unicode.ConvertGBToUnicode
Resource_Unicode_ConvertSJISToUnicode = Resource_Unicode.ConvertSJISToUnicode
Resource_Unicode_ConvertUnicodeToANSI = Resource_Unicode.ConvertUnicodeToANSI
Resource_Unicode_ConvertUnicodeToEUC = Resource_Unicode.ConvertUnicodeToEUC
Resource_Unicode_ConvertUnicodeToFormat = Resource_Unicode.ConvertUnicodeToFormat
Resource_Unicode_ConvertUnicodeToFormat = Resource_Unicode.ConvertUnicodeToFormat
Resource_Unicode_ConvertUnicodeToGB = Resource_Unicode.ConvertUnicodeToGB
Resource_Unicode_ConvertUnicodeToSJIS = Resource_Unicode.ConvertUnicodeToSJIS
Resource_Unicode_GetFormat = Resource_Unicode.GetFormat
Resource_Unicode_ReadFormat = Resource_Unicode.ReadFormat
Resource_Unicode_SetFormat = Resource_Unicode.SetFormat



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Geom import *
from OCC.Core.Geom2d import *


class hermit:
	@overload
	@staticmethod
	def Solution(BS: Geom_BSplineCurve, TolPoles: Optional[float] = 0.000001, TolKnots: Optional[float] = 0.000001) -> Geom2d_BSplineCurve: ...
	@overload
	@staticmethod
	def Solution(BS: Geom2d_BSplineCurve, TolPoles: Optional[float] = 0.000001, TolKnots: Optional[float] = 0.000001) -> Geom2d_BSplineCurve: ...
	@staticmethod
	def Solutionbis(BS: Geom_BSplineCurve, TolPoles: Optional[float] = 0.000001, TolKnots: Optional[float] = 0.000001) -> Tuple[float, float]: ...

# harray1 classes
# harray2 classes
# hsequence classes

hermit_Solution = hermit.Solution
hermit_Solution = hermit.Solution
hermit_Solutionbis = hermit.Solutionbis



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
RWStepFEA module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_rwstepfea.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _RWStepFEA
else:
    import _RWStepFEA

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _RWStepFEA.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _RWStepFEA.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepFEA.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepFEA.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _RWStepFEA.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _RWStepFEA.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _RWStepFEA.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _RWStepFEA.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _RWStepFEA.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _RWStepFEA.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepFEA.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepFEA.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepFEA.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepFEA.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepFEA.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepFEA.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _RWStepFEA.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _RWStepFEA:
_RWStepFEA.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _RWStepFEA.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepFEA
import OCC.Core.StepElement
import OCC.Core.StepRepr
import OCC.Core.StepBasic
import OCC.Core.StepGeom

from enum import IntEnum
from OCC.Core.Exception import *



class RWStepFEA_RWAlignedCurve3dElementCoordinateSystem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWAlignedCurve3dElementCoordinateSystem_swiginit(self, _RWStepFEA.new_RWStepFEA_RWAlignedCurve3dElementCoordinateSystem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads alignedcurve3delementcoordinatesystem.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_AlignedCurve3dElementCoordinateSystem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWAlignedCurve3dElementCoordinateSystem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_AlignedCurve3dElementCoordinateSystem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWAlignedCurve3dElementCoordinateSystem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes alignedcurve3delementcoordinatesystem.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_AlignedCurve3dElementCoordinateSystem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWAlignedCurve3dElementCoordinateSystem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWAlignedCurve3dElementCoordinateSystem

# Register RWStepFEA_RWAlignedCurve3dElementCoordinateSystem in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWAlignedCurve3dElementCoordinateSystem_swigregister(RWStepFEA_RWAlignedCurve3dElementCoordinateSystem)

class RWStepFEA_RWAlignedSurface3dElementCoordinateSystem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWAlignedSurface3dElementCoordinateSystem_swiginit(self, _RWStepFEA.new_RWStepFEA_RWAlignedSurface3dElementCoordinateSystem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads alignedsurface3delementcoordinatesystem.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_AlignedSurface3dElementCoordinateSystem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWAlignedSurface3dElementCoordinateSystem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_AlignedSurface3dElementCoordinateSystem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWAlignedSurface3dElementCoordinateSystem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes alignedsurface3delementcoordinatesystem.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_AlignedSurface3dElementCoordinateSystem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWAlignedSurface3dElementCoordinateSystem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWAlignedSurface3dElementCoordinateSystem

# Register RWStepFEA_RWAlignedSurface3dElementCoordinateSystem in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWAlignedSurface3dElementCoordinateSystem_swigregister(RWStepFEA_RWAlignedSurface3dElementCoordinateSystem)

class RWStepFEA_RWArbitraryVolume3dElementCoordinateSystem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWArbitraryVolume3dElementCoordinateSystem_swiginit(self, _RWStepFEA.new_RWStepFEA_RWArbitraryVolume3dElementCoordinateSystem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads arbitraryvolume3delementcoordinatesystem.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_ArbitraryVolume3dElementCoordinateSystem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWArbitraryVolume3dElementCoordinateSystem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_ArbitraryVolume3dElementCoordinateSystem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWArbitraryVolume3dElementCoordinateSystem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes arbitraryvolume3delementcoordinatesystem.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_ArbitraryVolume3dElementCoordinateSystem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWArbitraryVolume3dElementCoordinateSystem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWArbitraryVolume3dElementCoordinateSystem

# Register RWStepFEA_RWArbitraryVolume3dElementCoordinateSystem in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWArbitraryVolume3dElementCoordinateSystem_swigregister(RWStepFEA_RWArbitraryVolume3dElementCoordinateSystem)

class RWStepFEA_RWConstantSurface3dElementCoordinateSystem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWConstantSurface3dElementCoordinateSystem_swiginit(self, _RWStepFEA.new_RWStepFEA_RWConstantSurface3dElementCoordinateSystem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads constantsurface3delementcoordinatesystem.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_ConstantSurface3dElementCoordinateSystem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWConstantSurface3dElementCoordinateSystem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_ConstantSurface3dElementCoordinateSystem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWConstantSurface3dElementCoordinateSystem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes constantsurface3delementcoordinatesystem.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_ConstantSurface3dElementCoordinateSystem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWConstantSurface3dElementCoordinateSystem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWConstantSurface3dElementCoordinateSystem

# Register RWStepFEA_RWConstantSurface3dElementCoordinateSystem in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWConstantSurface3dElementCoordinateSystem_swigregister(RWStepFEA_RWConstantSurface3dElementCoordinateSystem)

class RWStepFEA_RWCurve3dElementProperty(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWCurve3dElementProperty_swiginit(self, _RWStepFEA.new_RWStepFEA_RWCurve3dElementProperty(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads curve3delementproperty.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_Curve3dElementProperty

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurve3dElementProperty_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_Curve3dElementProperty
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurve3dElementProperty_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes curve3delementproperty.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_Curve3dElementProperty

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurve3dElementProperty_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWCurve3dElementProperty

# Register RWStepFEA_RWCurve3dElementProperty in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWCurve3dElementProperty_swigregister(RWStepFEA_RWCurve3dElementProperty)

class RWStepFEA_RWCurve3dElementRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWCurve3dElementRepresentation_swiginit(self, _RWStepFEA.new_RWStepFEA_RWCurve3dElementRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads curve3delementrepresentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_Curve3dElementRepresentation

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurve3dElementRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_Curve3dElementRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurve3dElementRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes curve3delementrepresentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_Curve3dElementRepresentation

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurve3dElementRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWCurve3dElementRepresentation

# Register RWStepFEA_RWCurve3dElementRepresentation in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWCurve3dElementRepresentation_swigregister(RWStepFEA_RWCurve3dElementRepresentation)

class RWStepFEA_RWCurveElementEndOffset(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWCurveElementEndOffset_swiginit(self, _RWStepFEA.new_RWStepFEA_RWCurveElementEndOffset(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads curveelementendoffset.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_CurveElementEndOffset

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementEndOffset_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_CurveElementEndOffset
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementEndOffset_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes curveelementendoffset.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_CurveElementEndOffset

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementEndOffset_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWCurveElementEndOffset

# Register RWStepFEA_RWCurveElementEndOffset in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWCurveElementEndOffset_swigregister(RWStepFEA_RWCurveElementEndOffset)

class RWStepFEA_RWCurveElementEndRelease(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWCurveElementEndRelease_swiginit(self, _RWStepFEA.new_RWStepFEA_RWCurveElementEndRelease(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads curveelementendrelease.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_CurveElementEndRelease

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementEndRelease_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_CurveElementEndRelease
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementEndRelease_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes curveelementendrelease.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_CurveElementEndRelease

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementEndRelease_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWCurveElementEndRelease

# Register RWStepFEA_RWCurveElementEndRelease in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWCurveElementEndRelease_swigregister(RWStepFEA_RWCurveElementEndRelease)

class RWStepFEA_RWCurveElementInterval(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWCurveElementInterval_swiginit(self, _RWStepFEA.new_RWStepFEA_RWCurveElementInterval(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads curveelementinterval.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_CurveElementInterval

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementInterval_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_CurveElementInterval
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementInterval_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes curveelementinterval.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_CurveElementInterval

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementInterval_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWCurveElementInterval

# Register RWStepFEA_RWCurveElementInterval in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWCurveElementInterval_swigregister(RWStepFEA_RWCurveElementInterval)

class RWStepFEA_RWCurveElementIntervalConstant(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWCurveElementIntervalConstant_swiginit(self, _RWStepFEA.new_RWStepFEA_RWCurveElementIntervalConstant(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads curveelementintervalconstant.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_CurveElementIntervalConstant

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementIntervalConstant_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_CurveElementIntervalConstant
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementIntervalConstant_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes curveelementintervalconstant.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_CurveElementIntervalConstant

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementIntervalConstant_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWCurveElementIntervalConstant

# Register RWStepFEA_RWCurveElementIntervalConstant in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWCurveElementIntervalConstant_swigregister(RWStepFEA_RWCurveElementIntervalConstant)

class RWStepFEA_RWCurveElementIntervalLinearlyVarying(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWCurveElementIntervalLinearlyVarying_swiginit(self, _RWStepFEA.new_RWStepFEA_RWCurveElementIntervalLinearlyVarying(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads curveelementintervallinearlyvarying.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_CurveElementIntervalLinearlyVarying

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementIntervalLinearlyVarying_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_CurveElementIntervalLinearlyVarying
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementIntervalLinearlyVarying_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes curveelementintervallinearlyvarying.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_CurveElementIntervalLinearlyVarying

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementIntervalLinearlyVarying_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWCurveElementIntervalLinearlyVarying

# Register RWStepFEA_RWCurveElementIntervalLinearlyVarying in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWCurveElementIntervalLinearlyVarying_swigregister(RWStepFEA_RWCurveElementIntervalLinearlyVarying)

class RWStepFEA_RWCurveElementLocation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWCurveElementLocation_swiginit(self, _RWStepFEA.new_RWStepFEA_RWCurveElementLocation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads curveelementlocation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_CurveElementLocation

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementLocation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_CurveElementLocation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementLocation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes curveelementlocation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_CurveElementLocation

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWCurveElementLocation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWCurveElementLocation

# Register RWStepFEA_RWCurveElementLocation in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWCurveElementLocation_swigregister(RWStepFEA_RWCurveElementLocation)

class RWStepFEA_RWDummyNode(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWDummyNode_swiginit(self, _RWStepFEA.new_RWStepFEA_RWDummyNode(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads dummynode.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_DummyNode

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWDummyNode_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_DummyNode
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWDummyNode_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes dummynode.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_DummyNode

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWDummyNode_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWDummyNode

# Register RWStepFEA_RWDummyNode in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWDummyNode_swigregister(RWStepFEA_RWDummyNode)

class RWStepFEA_RWElementGeometricRelationship(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWElementGeometricRelationship_swiginit(self, _RWStepFEA.new_RWStepFEA_RWElementGeometricRelationship(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads elementgeometricrelationship.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_ElementGeometricRelationship

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWElementGeometricRelationship_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_ElementGeometricRelationship
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWElementGeometricRelationship_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes elementgeometricrelationship.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_ElementGeometricRelationship

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWElementGeometricRelationship_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWElementGeometricRelationship

# Register RWStepFEA_RWElementGeometricRelationship in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWElementGeometricRelationship_swigregister(RWStepFEA_RWElementGeometricRelationship)

class RWStepFEA_RWElementGroup(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWElementGroup_swiginit(self, _RWStepFEA.new_RWStepFEA_RWElementGroup(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads elementgroup.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_ElementGroup

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWElementGroup_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_ElementGroup
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWElementGroup_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes elementgroup.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_ElementGroup

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWElementGroup_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWElementGroup

# Register RWStepFEA_RWElementGroup in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWElementGroup_swigregister(RWStepFEA_RWElementGroup)

class RWStepFEA_RWElementRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWElementRepresentation_swiginit(self, _RWStepFEA.new_RWStepFEA_RWElementRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads elementrepresentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_ElementRepresentation

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWElementRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_ElementRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWElementRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes elementrepresentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_ElementRepresentation

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWElementRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWElementRepresentation

# Register RWStepFEA_RWElementRepresentation in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWElementRepresentation_swigregister(RWStepFEA_RWElementRepresentation)

class RWStepFEA_RWFeaAreaDensity(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaAreaDensity_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaAreaDensity(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feaareadensity.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaAreaDensity

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaAreaDensity_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaAreaDensity
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaAreaDensity_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feaareadensity.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaAreaDensity

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaAreaDensity_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaAreaDensity

# Register RWStepFEA_RWFeaAreaDensity in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaAreaDensity_swigregister(RWStepFEA_RWFeaAreaDensity)

class RWStepFEA_RWFeaAxis2Placement3d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaAxis2Placement3d_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaAxis2Placement3d(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feaaxis2placement3d.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaAxis2Placement3d

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaAxis2Placement3d_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaAxis2Placement3d
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaAxis2Placement3d_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feaaxis2placement3d.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaAxis2Placement3d

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaAxis2Placement3d_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaAxis2Placement3d

# Register RWStepFEA_RWFeaAxis2Placement3d in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaAxis2Placement3d_swigregister(RWStepFEA_RWFeaAxis2Placement3d)

class RWStepFEA_RWFeaCurveSectionGeometricRelationship(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaCurveSectionGeometricRelationship_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaCurveSectionGeometricRelationship(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feacurvesectiongeometricrelationship.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaCurveSectionGeometricRelationship

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaCurveSectionGeometricRelationship_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaCurveSectionGeometricRelationship
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaCurveSectionGeometricRelationship_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feacurvesectiongeometricrelationship.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaCurveSectionGeometricRelationship

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaCurveSectionGeometricRelationship_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaCurveSectionGeometricRelationship

# Register RWStepFEA_RWFeaCurveSectionGeometricRelationship in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaCurveSectionGeometricRelationship_swigregister(RWStepFEA_RWFeaCurveSectionGeometricRelationship)

class RWStepFEA_RWFeaGroup(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaGroup_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaGroup(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feagroup.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaGroup

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaGroup_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaGroup
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaGroup_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feagroup.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaGroup

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaGroup_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaGroup

# Register RWStepFEA_RWFeaGroup in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaGroup_swigregister(RWStepFEA_RWFeaGroup)

class RWStepFEA_RWFeaLinearElasticity(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaLinearElasticity_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaLinearElasticity(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads fealinearelasticity.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaLinearElasticity

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaLinearElasticity_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaLinearElasticity
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaLinearElasticity_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes fealinearelasticity.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaLinearElasticity

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaLinearElasticity_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaLinearElasticity

# Register RWStepFEA_RWFeaLinearElasticity in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaLinearElasticity_swigregister(RWStepFEA_RWFeaLinearElasticity)

class RWStepFEA_RWFeaMassDensity(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaMassDensity_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaMassDensity(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feamassdensity.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaMassDensity

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaMassDensity_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaMassDensity
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaMassDensity_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feamassdensity.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaMassDensity

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaMassDensity_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaMassDensity

# Register RWStepFEA_RWFeaMassDensity in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaMassDensity_swigregister(RWStepFEA_RWFeaMassDensity)

class RWStepFEA_RWFeaMaterialPropertyRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaMaterialPropertyRepresentation_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaMaterialPropertyRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feamaterialpropertyrepresentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaMaterialPropertyRepresentation

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaMaterialPropertyRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaMaterialPropertyRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaMaterialPropertyRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feamaterialpropertyrepresentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaMaterialPropertyRepresentation

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaMaterialPropertyRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaMaterialPropertyRepresentation

# Register RWStepFEA_RWFeaMaterialPropertyRepresentation in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaMaterialPropertyRepresentation_swigregister(RWStepFEA_RWFeaMaterialPropertyRepresentation)

class RWStepFEA_RWFeaMaterialPropertyRepresentationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaMaterialPropertyRepresentationItem_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaMaterialPropertyRepresentationItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feamaterialpropertyrepresentationitem.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaMaterialPropertyRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaMaterialPropertyRepresentationItem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaMaterialPropertyRepresentationItem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaMaterialPropertyRepresentationItem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feamaterialpropertyrepresentationitem.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaMaterialPropertyRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaMaterialPropertyRepresentationItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaMaterialPropertyRepresentationItem

# Register RWStepFEA_RWFeaMaterialPropertyRepresentationItem in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaMaterialPropertyRepresentationItem_swigregister(RWStepFEA_RWFeaMaterialPropertyRepresentationItem)

class RWStepFEA_RWFeaModel(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaModel_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaModel(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feamodel.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaModel

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaModel_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaModel
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaModel_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feamodel.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaModel

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaModel_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaModel

# Register RWStepFEA_RWFeaModel in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaModel_swigregister(RWStepFEA_RWFeaModel)

class RWStepFEA_RWFeaModel3d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaModel3d_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaModel3d(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feamodel3d.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaModel3d

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaModel3d_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaModel3d
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaModel3d_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feamodel3d.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaModel3d

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaModel3d_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaModel3d

# Register RWStepFEA_RWFeaModel3d in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaModel3d_swigregister(RWStepFEA_RWFeaModel3d)

class RWStepFEA_RWFeaModelDefinition(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaModelDefinition_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaModelDefinition(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feamodeldefinition.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaModelDefinition

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaModelDefinition_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaModelDefinition
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaModelDefinition_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feamodeldefinition.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaModelDefinition

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaModelDefinition_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaModelDefinition

# Register RWStepFEA_RWFeaModelDefinition in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaModelDefinition_swigregister(RWStepFEA_RWFeaModelDefinition)

class RWStepFEA_RWFeaMoistureAbsorption(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaMoistureAbsorption_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaMoistureAbsorption(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feamoistureabsorption.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaMoistureAbsorption

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaMoistureAbsorption_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaMoistureAbsorption
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaMoistureAbsorption_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feamoistureabsorption.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaMoistureAbsorption

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaMoistureAbsorption_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaMoistureAbsorption

# Register RWStepFEA_RWFeaMoistureAbsorption in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaMoistureAbsorption_swigregister(RWStepFEA_RWFeaMoistureAbsorption)

class RWStepFEA_RWFeaParametricPoint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaParametricPoint_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaParametricPoint(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feaparametricpoint.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaParametricPoint

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaParametricPoint_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaParametricPoint
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaParametricPoint_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feaparametricpoint.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaParametricPoint

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaParametricPoint_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaParametricPoint

# Register RWStepFEA_RWFeaParametricPoint in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaParametricPoint_swigregister(RWStepFEA_RWFeaParametricPoint)

class RWStepFEA_RWFeaRepresentationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaRepresentationItem_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaRepresentationItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads fearepresentationitem.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaRepresentationItem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaRepresentationItem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaRepresentationItem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes fearepresentationitem.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaRepresentationItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaRepresentationItem

# Register RWStepFEA_RWFeaRepresentationItem in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaRepresentationItem_swigregister(RWStepFEA_RWFeaRepresentationItem)

class RWStepFEA_RWFeaSecantCoefficientOfLinearThermalExpansion(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaSecantCoefficientOfLinearThermalExpansion_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaSecantCoefficientOfLinearThermalExpansion(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feasecantcoefficientoflinearthermalexpansion.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaSecantCoefficientOfLinearThermalExpansion

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaSecantCoefficientOfLinearThermalExpansion_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaSecantCoefficientOfLinearThermalExpansion
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaSecantCoefficientOfLinearThermalExpansion_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feasecantcoefficientoflinearthermalexpansion.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaSecantCoefficientOfLinearThermalExpansion

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaSecantCoefficientOfLinearThermalExpansion_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaSecantCoefficientOfLinearThermalExpansion

# Register RWStepFEA_RWFeaSecantCoefficientOfLinearThermalExpansion in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaSecantCoefficientOfLinearThermalExpansion_swigregister(RWStepFEA_RWFeaSecantCoefficientOfLinearThermalExpansion)

class RWStepFEA_RWFeaShellBendingStiffness(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaShellBendingStiffness_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaShellBendingStiffness(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feashellbendingstiffness.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaShellBendingStiffness

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaShellBendingStiffness_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaShellBendingStiffness
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaShellBendingStiffness_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feashellbendingstiffness.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaShellBendingStiffness

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaShellBendingStiffness_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaShellBendingStiffness

# Register RWStepFEA_RWFeaShellBendingStiffness in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaShellBendingStiffness_swigregister(RWStepFEA_RWFeaShellBendingStiffness)

class RWStepFEA_RWFeaShellMembraneBendingCouplingStiffness(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaShellMembraneBendingCouplingStiffness_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaShellMembraneBendingCouplingStiffness(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feashellmembranebendingcouplingstiffness.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaShellMembraneBendingCouplingStiffness

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaShellMembraneBendingCouplingStiffness_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaShellMembraneBendingCouplingStiffness
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaShellMembraneBendingCouplingStiffness_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feashellmembranebendingcouplingstiffness.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaShellMembraneBendingCouplingStiffness

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaShellMembraneBendingCouplingStiffness_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaShellMembraneBendingCouplingStiffness

# Register RWStepFEA_RWFeaShellMembraneBendingCouplingStiffness in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaShellMembraneBendingCouplingStiffness_swigregister(RWStepFEA_RWFeaShellMembraneBendingCouplingStiffness)

class RWStepFEA_RWFeaShellMembraneStiffness(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaShellMembraneStiffness_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaShellMembraneStiffness(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feashellmembranestiffness.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaShellMembraneStiffness

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaShellMembraneStiffness_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaShellMembraneStiffness
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaShellMembraneStiffness_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feashellmembranestiffness.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaShellMembraneStiffness

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaShellMembraneStiffness_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaShellMembraneStiffness

# Register RWStepFEA_RWFeaShellMembraneStiffness in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaShellMembraneStiffness_swigregister(RWStepFEA_RWFeaShellMembraneStiffness)

class RWStepFEA_RWFeaShellShearStiffness(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaShellShearStiffness_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaShellShearStiffness(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feashellshearstiffness.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaShellShearStiffness

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaShellShearStiffness_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaShellShearStiffness
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaShellShearStiffness_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feashellshearstiffness.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaShellShearStiffness

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaShellShearStiffness_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaShellShearStiffness

# Register RWStepFEA_RWFeaShellShearStiffness in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaShellShearStiffness_swigregister(RWStepFEA_RWFeaShellShearStiffness)

class RWStepFEA_RWFeaSurfaceSectionGeometricRelationship(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaSurfaceSectionGeometricRelationship_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaSurfaceSectionGeometricRelationship(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads feasurfacesectiongeometricrelationship.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaSurfaceSectionGeometricRelationship

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaSurfaceSectionGeometricRelationship_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaSurfaceSectionGeometricRelationship
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaSurfaceSectionGeometricRelationship_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes feasurfacesectiongeometricrelationship.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaSurfaceSectionGeometricRelationship

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaSurfaceSectionGeometricRelationship_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaSurfaceSectionGeometricRelationship

# Register RWStepFEA_RWFeaSurfaceSectionGeometricRelationship in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaSurfaceSectionGeometricRelationship_swigregister(RWStepFEA_RWFeaSurfaceSectionGeometricRelationship)

class RWStepFEA_RWFeaTangentialCoefficientOfLinearThermalExpansion(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFeaTangentialCoefficientOfLinearThermalExpansion_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFeaTangentialCoefficientOfLinearThermalExpansion(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads featangentialcoefficientoflinearthermalexpansion.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaTangentialCoefficientOfLinearThermalExpansion_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaTangentialCoefficientOfLinearThermalExpansion_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes featangentialcoefficientoflinearthermalexpansion.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFeaTangentialCoefficientOfLinearThermalExpansion_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFeaTangentialCoefficientOfLinearThermalExpansion

# Register RWStepFEA_RWFeaTangentialCoefficientOfLinearThermalExpansion in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFeaTangentialCoefficientOfLinearThermalExpansion_swigregister(RWStepFEA_RWFeaTangentialCoefficientOfLinearThermalExpansion)

class RWStepFEA_RWFreedomAndCoefficient(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFreedomAndCoefficient_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFreedomAndCoefficient(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads freedomandcoefficient.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FreedomAndCoefficient

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFreedomAndCoefficient_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FreedomAndCoefficient
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFreedomAndCoefficient_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes freedomandcoefficient.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FreedomAndCoefficient

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFreedomAndCoefficient_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFreedomAndCoefficient

# Register RWStepFEA_RWFreedomAndCoefficient in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFreedomAndCoefficient_swigregister(RWStepFEA_RWFreedomAndCoefficient)

class RWStepFEA_RWFreedomsList(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWFreedomsList_swiginit(self, _RWStepFEA.new_RWStepFEA_RWFreedomsList(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads freedomslist.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_FreedomsList

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFreedomsList_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_FreedomsList
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFreedomsList_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes freedomslist.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_FreedomsList

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWFreedomsList_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWFreedomsList

# Register RWStepFEA_RWFreedomsList in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWFreedomsList_swigregister(RWStepFEA_RWFreedomsList)

class RWStepFEA_RWGeometricNode(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWGeometricNode_swiginit(self, _RWStepFEA.new_RWStepFEA_RWGeometricNode(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads geometricnode.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_GeometricNode

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWGeometricNode_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_GeometricNode
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWGeometricNode_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes geometricnode.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_GeometricNode

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWGeometricNode_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWGeometricNode

# Register RWStepFEA_RWGeometricNode in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWGeometricNode_swigregister(RWStepFEA_RWGeometricNode)

class RWStepFEA_RWNode(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWNode_swiginit(self, _RWStepFEA.new_RWStepFEA_RWNode(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads node.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_Node

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNode_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_Node
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNode_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes node.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_Node

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNode_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWNode

# Register RWStepFEA_RWNode in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWNode_swigregister(RWStepFEA_RWNode)

class RWStepFEA_RWNodeDefinition(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWNodeDefinition_swiginit(self, _RWStepFEA.new_RWStepFEA_RWNodeDefinition(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads nodedefinition.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_NodeDefinition

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeDefinition_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_NodeDefinition
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeDefinition_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes nodedefinition.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_NodeDefinition

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeDefinition_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWNodeDefinition

# Register RWStepFEA_RWNodeDefinition in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWNodeDefinition_swigregister(RWStepFEA_RWNodeDefinition)

class RWStepFEA_RWNodeGroup(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWNodeGroup_swiginit(self, _RWStepFEA.new_RWStepFEA_RWNodeGroup(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads nodegroup.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_NodeGroup

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeGroup_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_NodeGroup
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeGroup_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes nodegroup.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_NodeGroup

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeGroup_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWNodeGroup

# Register RWStepFEA_RWNodeGroup in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWNodeGroup_swigregister(RWStepFEA_RWNodeGroup)

class RWStepFEA_RWNodeRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWNodeRepresentation_swiginit(self, _RWStepFEA.new_RWStepFEA_RWNodeRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads noderepresentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_NodeRepresentation

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_NodeRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes noderepresentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_NodeRepresentation

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWNodeRepresentation

# Register RWStepFEA_RWNodeRepresentation in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWNodeRepresentation_swigregister(RWStepFEA_RWNodeRepresentation)

class RWStepFEA_RWNodeSet(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWNodeSet_swiginit(self, _RWStepFEA.new_RWStepFEA_RWNodeSet(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads nodeset.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_NodeSet

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeSet_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_NodeSet
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeSet_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes nodeset.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_NodeSet

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeSet_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWNodeSet

# Register RWStepFEA_RWNodeSet in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWNodeSet_swigregister(RWStepFEA_RWNodeSet)

class RWStepFEA_RWNodeWithSolutionCoordinateSystem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWNodeWithSolutionCoordinateSystem_swiginit(self, _RWStepFEA.new_RWStepFEA_RWNodeWithSolutionCoordinateSystem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads nodewithsolutioncoordinatesystem.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_NodeWithSolutionCoordinateSystem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeWithSolutionCoordinateSystem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_NodeWithSolutionCoordinateSystem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeWithSolutionCoordinateSystem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes nodewithsolutioncoordinatesystem.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_NodeWithSolutionCoordinateSystem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeWithSolutionCoordinateSystem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWNodeWithSolutionCoordinateSystem

# Register RWStepFEA_RWNodeWithSolutionCoordinateSystem in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWNodeWithSolutionCoordinateSystem_swigregister(RWStepFEA_RWNodeWithSolutionCoordinateSystem)

class RWStepFEA_RWNodeWithVector(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWNodeWithVector_swiginit(self, _RWStepFEA.new_RWStepFEA_RWNodeWithVector(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads nodewithvector.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_NodeWithVector

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeWithVector_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_NodeWithVector
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeWithVector_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes nodewithvector.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_NodeWithVector

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWNodeWithVector_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWNodeWithVector

# Register RWStepFEA_RWNodeWithVector in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWNodeWithVector_swigregister(RWStepFEA_RWNodeWithVector)

class RWStepFEA_RWParametricCurve3dElementCoordinateDirection(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWParametricCurve3dElementCoordinateDirection_swiginit(self, _RWStepFEA.new_RWStepFEA_RWParametricCurve3dElementCoordinateDirection(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads parametriccurve3delementcoordinatedirection.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_ParametricCurve3dElementCoordinateDirection

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWParametricCurve3dElementCoordinateDirection_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_ParametricCurve3dElementCoordinateDirection
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWParametricCurve3dElementCoordinateDirection_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes parametriccurve3delementcoordinatedirection.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_ParametricCurve3dElementCoordinateDirection

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWParametricCurve3dElementCoordinateDirection_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWParametricCurve3dElementCoordinateDirection

# Register RWStepFEA_RWParametricCurve3dElementCoordinateDirection in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWParametricCurve3dElementCoordinateDirection_swigregister(RWStepFEA_RWParametricCurve3dElementCoordinateDirection)

class RWStepFEA_RWParametricCurve3dElementCoordinateSystem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWParametricCurve3dElementCoordinateSystem_swiginit(self, _RWStepFEA.new_RWStepFEA_RWParametricCurve3dElementCoordinateSystem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads parametriccurve3delementcoordinatesystem.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_ParametricCurve3dElementCoordinateSystem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWParametricCurve3dElementCoordinateSystem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_ParametricCurve3dElementCoordinateSystem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWParametricCurve3dElementCoordinateSystem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes parametriccurve3delementcoordinatesystem.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_ParametricCurve3dElementCoordinateSystem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWParametricCurve3dElementCoordinateSystem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWParametricCurve3dElementCoordinateSystem

# Register RWStepFEA_RWParametricCurve3dElementCoordinateSystem in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWParametricCurve3dElementCoordinateSystem_swigregister(RWStepFEA_RWParametricCurve3dElementCoordinateSystem)

class RWStepFEA_RWParametricSurface3dElementCoordinateSystem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWParametricSurface3dElementCoordinateSystem_swiginit(self, _RWStepFEA.new_RWStepFEA_RWParametricSurface3dElementCoordinateSystem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads parametricsurface3delementcoordinatesystem.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_ParametricSurface3dElementCoordinateSystem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWParametricSurface3dElementCoordinateSystem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_ParametricSurface3dElementCoordinateSystem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWParametricSurface3dElementCoordinateSystem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes parametricsurface3delementcoordinatesystem.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_ParametricSurface3dElementCoordinateSystem

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWParametricSurface3dElementCoordinateSystem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWParametricSurface3dElementCoordinateSystem

# Register RWStepFEA_RWParametricSurface3dElementCoordinateSystem in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWParametricSurface3dElementCoordinateSystem_swigregister(RWStepFEA_RWParametricSurface3dElementCoordinateSystem)

class RWStepFEA_RWSurface3dElementRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWSurface3dElementRepresentation_swiginit(self, _RWStepFEA.new_RWStepFEA_RWSurface3dElementRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads surface3delementrepresentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_Surface3dElementRepresentation

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWSurface3dElementRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_Surface3dElementRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWSurface3dElementRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes surface3delementrepresentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_Surface3dElementRepresentation

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWSurface3dElementRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWSurface3dElementRepresentation

# Register RWStepFEA_RWSurface3dElementRepresentation in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWSurface3dElementRepresentation_swigregister(RWStepFEA_RWSurface3dElementRepresentation)

class RWStepFEA_RWVolume3dElementRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepFEA.RWStepFEA_RWVolume3dElementRepresentation_swiginit(self, _RWStepFEA.new_RWStepFEA_RWVolume3dElementRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads volume3delementrepresentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepFEA_Volume3dElementRepresentation

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWVolume3dElementRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepFEA_Volume3dElementRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWVolume3dElementRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes volume3delementrepresentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepFEA_Volume3dElementRepresentation

        Returns
        -------
        None

        """
        return _RWStepFEA.RWStepFEA_RWVolume3dElementRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepFEA.delete_RWStepFEA_RWVolume3dElementRepresentation

# Register RWStepFEA_RWVolume3dElementRepresentation in _RWStepFEA:
_RWStepFEA.RWStepFEA_RWVolume3dElementRepresentation_swigregister(RWStepFEA_RWVolume3dElementRepresentation)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.Geom2d import *
from OCC.Core.gce import *


class GCE2d_MakeMirror:
	@overload
	def __init__(self, Point: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, Axis: gp_Ax2d) -> None: ...
	@overload
	def __init__(self, Line: gp_Lin2d) -> None: ...
	@overload
	def __init__(self, Point: gp_Pnt2d, Direc: gp_Dir2d) -> None: ...
	def Value(self) -> Geom2d_Transformation: ...

class GCE2d_MakeRotation:
	def __init__(self, Point: gp_Pnt2d, Angle: float) -> None: ...
	def Value(self) -> Geom2d_Transformation: ...

class GCE2d_MakeScale:
	def __init__(self, Point: gp_Pnt2d, Scale: float) -> None: ...
	def Value(self) -> Geom2d_Transformation: ...

class GCE2d_MakeTranslation:
	@overload
	def __init__(self, Vect: gp_Vec2d) -> None: ...
	@overload
	def __init__(self, Point1: gp_Pnt2d, Point2: gp_Pnt2d) -> None: ...
	def Value(self) -> Geom2d_Transformation: ...

class GCE2d_Root:
	def IsDone(self) -> bool: ...
	def Status(self) -> gce_ErrorType: ...

class GCE2d_MakeArcOfCircle(GCE2d_Root):
	@overload
	def __init__(self, Circ: gp_Circ2d, Alpha1: float, Alpha2: float, Sense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Circ: gp_Circ2d, P: gp_Pnt2d, Alpha: float, Sense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Circ: gp_Circ2d, P1: gp_Pnt2d, P2: gp_Pnt2d, Sense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt2d, P2: gp_Pnt2d, P3: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt2d, V: gp_Vec2d, P2: gp_Pnt2d) -> None: ...
	def Value(self) -> Geom2d_TrimmedCurve: ...

class GCE2d_MakeArcOfEllipse(GCE2d_Root):
	@overload
	def __init__(self, Elips: gp_Elips2d, Alpha1: float, Alpha2: float, Sense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Elips: gp_Elips2d, P: gp_Pnt2d, Alpha: float, Sense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Elips: gp_Elips2d, P1: gp_Pnt2d, P2: gp_Pnt2d, Sense: Optional[bool] = True) -> None: ...
	def Value(self) -> Geom2d_TrimmedCurve: ...

class GCE2d_MakeArcOfHyperbola(GCE2d_Root):
	@overload
	def __init__(self, Hypr: gp_Hypr2d, Alpha1: float, Alpha2: float, Sense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Hypr: gp_Hypr2d, P: gp_Pnt2d, Alpha: float, Sense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Hypr: gp_Hypr2d, P1: gp_Pnt2d, P2: gp_Pnt2d, Sense: Optional[bool] = True) -> None: ...
	def Value(self) -> Geom2d_TrimmedCurve: ...

class GCE2d_MakeArcOfParabola(GCE2d_Root):
	@overload
	def __init__(self, Parab: gp_Parab2d, Alpha1: float, Alpha2: float, Sense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Parab: gp_Parab2d, P: gp_Pnt2d, Alpha: float, Sense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Parab: gp_Parab2d, P1: gp_Pnt2d, P2: gp_Pnt2d, Sense: Optional[bool] = True) -> None: ...
	def Value(self) -> Geom2d_TrimmedCurve: ...

class GCE2d_MakeCircle(GCE2d_Root):
	@overload
	def __init__(self, C: gp_Circ2d) -> None: ...
	@overload
	def __init__(self, A: gp_Ax2d, Radius: float, Sense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, A: gp_Ax22d, Radius: float) -> None: ...
	@overload
	def __init__(self, Circ: gp_Circ2d, Dist: float) -> None: ...
	@overload
	def __init__(self, Circ: gp_Circ2d, Point: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt2d, P2: gp_Pnt2d, P3: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt2d, Radius: float, Sense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Center: gp_Pnt2d, Point: gp_Pnt2d, Sense: Optional[bool] = True) -> None: ...
	def Value(self) -> Geom2d_Circle: ...

class GCE2d_MakeEllipse(GCE2d_Root):
	@overload
	def __init__(self, E: gp_Elips2d) -> None: ...
	@overload
	def __init__(self, MajorAxis: gp_Ax2d, MajorRadius: float, MinorRadius: float, Sense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Axis: gp_Ax22d, MajorRadius: float, MinorRadius: float) -> None: ...
	@overload
	def __init__(self, S1: gp_Pnt2d, S2: gp_Pnt2d, Center: gp_Pnt2d) -> None: ...
	def Value(self) -> Geom2d_Ellipse: ...

class GCE2d_MakeHyperbola(GCE2d_Root):
	@overload
	def __init__(self, H: gp_Hypr2d) -> None: ...
	@overload
	def __init__(self, MajorAxis: gp_Ax2d, MajorRadius: float, MinorRadius: float, Sense: bool) -> None: ...
	@overload
	def __init__(self, Axis: gp_Ax22d, MajorRadius: float, MinorRadius: float) -> None: ...
	@overload
	def __init__(self, S1: gp_Pnt2d, S2: gp_Pnt2d, Center: gp_Pnt2d) -> None: ...
	def Value(self) -> Geom2d_Hyperbola: ...

class GCE2d_MakeLine(GCE2d_Root):
	@overload
	def __init__(self, A: gp_Ax2d) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt2d, V: gp_Dir2d) -> None: ...
	@overload
	def __init__(self, Lin: gp_Lin2d, Point: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, Lin: gp_Lin2d, Dist: float) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	def Value(self) -> Geom2d_Line: ...

class GCE2d_MakeParabola(GCE2d_Root):
	@overload
	def __init__(self, Prb: gp_Parab2d) -> None: ...
	@overload
	def __init__(self, Axis: gp_Ax22d, Focal: float) -> None: ...
	@overload
	def __init__(self, MirrorAxis: gp_Ax2d, Focal: float, Sense: bool) -> None: ...
	@overload
	def __init__(self, D: gp_Ax2d, F: gp_Pnt2d, Sense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, S1: gp_Pnt2d, O: gp_Pnt2d) -> None: ...
	def Value(self) -> Geom2d_Parabola: ...

class GCE2d_MakeSegment(GCE2d_Root):
	@overload
	def __init__(self, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt2d, V: gp_Dir2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, Line: gp_Lin2d, U1: float, U2: float) -> None: ...
	@overload
	def __init__(self, Line: gp_Lin2d, Point: gp_Pnt2d, Ulast: float) -> None: ...
	@overload
	def __init__(self, Line: gp_Lin2d, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	def Value(self) -> Geom2d_TrimmedCurve: ...

# harray1 classes
# harray2 classes
# hsequence classes

